@@ -84,14 +84,12 @@ class SocketServerConnector(DeviceConnector):
     def read_device(self, socket: socket.socket, status: RecvStatus) -> Message:
         log(f"Socket Server Got Msg")
 
-        device = status.device
         if status.expected == 0:
             length_data = []
             while len(length_data) < DEFAULT_HEADER_LEN:
                 try:
                     length_data += socket.recv(DEFAULT_HEADER_LEN - len(length_data))
-                except BlockingIOError as err:
-                    log(f"Socket Connector Error Reading Device header {err}", logger_level="ERROR")
+                except BlockingIOError:
                     return None
                 except ConnectionResetError as err:
                     log(f"Socket Connector: Connection Reset Error Reading Device {err}", logger_level="ERROR")
@@ -107,9 +105,7 @@ class SocketServerConnector(DeviceConnector):
         while len(status.binary_data) < status.expected:
             try:
                 status.binary_data += socket.recv(status.expected - len(status.binary_data))
-            except BlockingIOError as err:
-                log(f"Socket Connector Error Reading Device payload {err}", logger_level="ERROR")
-                log(f"Already read {len(status.binary_data)} bytes", logger_level="ERROR")
+            except BlockingIOError:
                 return None
             except ConnectionResetError as err:
                 log(f"Socket Connector: Connection Reset Error Reading Device {err}", logger_level="ERROR")
@@ -167,8 +163,11 @@ class SocketServerConnector(DeviceConnector):
             log("Closing case 2", logger_level="ERROR")
             sock.close()
             dispatcher.notify(DeviceEvents.DISCONNECTED, status.device)
+        except BlockingIOError:
+            pass
         except Exception as e: 
             log(e, logger_level="ERROR")
+            raise e
 
         return did_something
 
@@ -187,7 +186,8 @@ class SocketServerConnector(DeviceConnector):
                             time.sleep(0.0001) # nothing was done so we give back then hand to the OS
         except KeyboardInterrupt:
             self._run = False
-        except:
+        except Exception as e:
+            log(e, logger_level="ERROR")
             traceback.print_exc()
         finally:
             log("Closing case 3")
